abacusai.llm_input — AbacusAI documentation

# abacusai.llm_input

## Classes

`LlmInput` | The result of encoding an object as input for a language model.

## Module Contents

class abacusai.llm_input.LlmInput(client, content=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  The result of encoding an object as input for a language model.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - content (str) – Content of the response

  content = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict